==> jboss-eap-6.0.1-src.zip: jboss-eap-6.0-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/sar/injection/pojos/AbstractService.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.test.integration.sar.injection.pojos;

/**
 * @author <a href="mailto:opalka.richard@gmail.com">Richard Opalka</a>
 */
abstract class AbstractService {
    
    private A a;
    
    public final void setA(final A a) {
        this.a = a;
    }

    public final int getCount() {
        return a.getCount();
    }

    public final boolean getStartCalled() {
        return a.getStartCalled();
    }

    public final boolean getStopCalled() {
        return a.getStopCalled();
    }

    public final boolean getCreateCalled() {
        return a.getCreateCalled();
    }

    public final boolean getDestroyCalled() {
        return a.getDestroyCalled();
    }

}

==> jboss-eap-6.4.21-src.zip: jboss-eap-6.4-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/sar/injection/pojos/AbstractService.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.test.integration.sar.injection.pojos;

/**
 * @author <a href="mailto:opalka.richard@gmail.com">Richard Opalka</a>
 */
abstract class AbstractService {
    
    private A a;
    private int injectedCount;
    
    public final void setA(final A a) {
        this.a = a;
    }

    public final int getCount() {
        return a.getCount();
    }

    public final int getInjectedCount() {
        return injectedCount;
    }

    public void setInjectedCount(int injectedCount) {
        this.injectedCount = injectedCount;
    }

    public final boolean getStartCalled() {
        return a.getStartCalled();
    }

    public final boolean getStopCalled() {
        return a.getStopCalled();
    }

    public final boolean getCreateCalled() {
        return a.getCreateCalled();
    }

    public final boolean getDestroyCalled() {
        return a.getDestroyCalled();
    }

}
